@@ -135,6 +135,15 @@ extern "C" {
 #  define MRN_HANDLER_AUTO_REPAIR_HAVE_ERROR
 #endif
 
+#if MYSQL_VERSION_ID < 50600
+#  define MRN_RBR_UPDATE_NEED_ALL_COLUMNS
+#endif
+
+#if MYSQL_VERSION_ID >= 50500
+#  define MRN_ROW_BASED_CHECK_IS_METHOD
+#  define MRN_OPTION_BITS_IS_UNDER_VARIABLES
+#endif
+
 class ha_mroonga;
 
 /* structs */
@@ -232,6 +241,7 @@ private:
   bool fulltext_searching;
   bool ignoring_no_key_columns;
   bool replacing_;
+  uint written_by_row_based_binlog;
 
 public:
   ha_mroonga(handlerton *hton, TABLE_SHARE *share_arg);
@@ -446,6 +456,7 @@ private:
   void clear_search_result_geo();
   void clear_indexes();
   int alter_share_add(const char *path, TABLE_SHARE *table_share);
+  void remove_related_files(const char *base_path);
   void remove_grn_obj_force(const char *name);
   grn_obj *find_tokenizer(const char *name, int name_length);
   int wrapper_get_next_record(uchar *buf);
@@ -838,6 +849,8 @@ private:
   int storage_enable_indexes(uint mode);
   int wrapper_check(THD* thd, HA_CHECK_OPT* check_opt);
   int storage_check(THD* thd, HA_CHECK_OPT* check_opt);
+  int wrapper_fill_indexes(THD *thd, KEY *key_info,
+                           grn_obj **index_columns, uint n_keys);
   int wrapper_recreate_indexes(THD *thd);
   int wrapper_repair(THD* thd, HA_CHECK_OPT* check_opt);
   int storage_repair(THD* thd, HA_CHECK_OPT* check_opt);
@@ -866,7 +879,8 @@ private:
 #endif
   int storage_add_index_multiple_columns(KEY *key_info, uint num_of_keys,
                                          grn_obj **index_tables,
-                                         grn_obj **index_columns);
+                                         grn_obj **index_columns,
+                                         bool skip_unique_key);
 #ifdef MRN_HANDLER_HAVE_FINAL_ADD_INDEX
   int wrapper_final_add_index(handler_add_index *add, bool commit);
   int storage_final_add_index(handler_add_index *add, bool commit);
@@ -931,6 +945,9 @@ private:
   void storage_init_table_handle_for_HANDLER();
   void wrapper_free_foreign_key_create_info(char* str);
   void storage_free_foreign_key_create_info(char* str);
+  void wrapper_set_keys_in_use();
+  void storage_set_keys_in_use();
+  bool check_written_by_row_based_binlog();
 };
 
 #ifdef __cplusplus
