@@ -496,6 +496,9 @@ int mrn_add_index_param(MRN_SHARE *share, KEY *key_info, int i)
 #if MYSQL_VERSION_ID >= 50500
   if (key_info->comment.length == 0)
   {
+    if (share->key_parser[i]) {
+      my_free(share->key_parser[i], MYF(0));
+    }
     if (
       !(share->key_parser[i] = mrn_create_string(
         mrn_default_parser,
@@ -703,6 +706,8 @@ MRN_SHARE *mrn_get_share(const char *table_name, TABLE *table, int *error)
       wrap_table_share->keys = share->wrap_keys;
       wrap_table_share->key_info = share->wrap_key_info;
       wrap_table_share->primary_key = share->wrap_primary_key;
+      wrap_table_share->keys_in_use.init(share->wrap_keys);
+      wrap_table_share->keys_for_keyread.init(share->wrap_keys);
       share->wrap_table_share = wrap_table_share;
     }
 
